
## CATO-CLI - query.servicePrincipalAdmin:
[Click here](https://api.catonetworks.com/documentation/#query-query.servicePrincipalAdmin) for documentation on this operation.

### Usage for query.servicePrincipalAdmin:

`catocli query servicePrincipalAdmin -h`

`catocli query servicePrincipalAdmin <json>`

`catocli query servicePrincipalAdmin "$(cat < query.servicePrincipalAdmin.json)"`

`catocli query servicePrincipalAdmin '{"adminID":"id"}'`

`catocli query servicePrincipalAdmin -p '{
    "adminID": "id"
}'`


#### Operation Arguments for query.servicePrincipalAdmin ####

`accountId` [ID] - (required) N/A    
`adminID` [ID] - (required) N/A    
